/*
  user_config_override.h - user configuration overrides my_user_config.h for Tasmota

  Copyright (C) 2020  Theo Arends

  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef _USER_CONFIG_OVERRIDE_H_
#define _USER_CONFIG_OVERRIDE_H_

// force the compiler to show a warning to confirm that this file is included
#warning **** user_config_override.h: Using Settings from this File ****

/*****************************************************************************************************\
 * USAGE:
 *   To modify the stock configuration without changing the my_user_config.h file:
 *   (1) copy this file to "user_config_override.h" (It will be ignored by Git)
 *   (2) define your own settings below
 ******************************************************************************************************
 * ATTENTION:
 *   - Changes to SECTION1 PARAMETER defines will only override flash settings if you change define CFG_HOLDER.
 *   - Expect compiler warnings when no ifdef/undef/endif sequence is used.
 *   - You still need to update my_user_config.h for major define USE_MQTT_TLS.
 *   - All parameters can be persistent changed online using commands via MQTT, WebConsole or Serial.
\*****************************************************************************************************/

// -- Master parameter control --------------------
#undef CFG_HOLDER
#define CFG_HOLDER             4617              // [Reset 1] Change this value (max 32000) to load SECTION1 configuration parameters to flash
//-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

#undef MODULE
//#define MODULE                 SHELLY1           // [Module] Select default model from tasmota_template.h
//#define MODULE                 SHELLY2           // [Module] Select default model from tasmota_template.h
//#define MODULE                 SONOFF_TOUCH      // [Module] Select default model from tasmota_template.h
//#define MODULE                 SONOFF_DUAL_R2    // [Module] Select default model from tasmota_template.h
//#define MODULE                 SONOFF_RF         // [Module] Select default model from tasmota_template.h
//#define MODULE                 BLITZWOLF_BWSHP   // [Module] Select default model from tasmota_template.h
//#define MODULE                 TUYA_DIMMER
//------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

//persöhnliches
#undef STA_SSID1
#define STA_SSID1              "DEINE SSID"                    // [Ssid1] Wifi SSID
#undef STA_PASS1
#define STA_PASS1              "DEIN PASSWORT"      // [Password1] Wifi password
#undef STA_SSID2
#define STA_SSID2              "DEINE SSID"                    // [Ssid2] Optional alternate AP Wifi SSID
#undef STA_PASS2
#define STA_PASS2              "DEIN PASSWORT"      // [Password2] Optional alternate AP Wifi password

#undef MQTT_HOST
#define MQTT_HOST              "IP VOM IOBROKER"            // [MqttHost]
#undef MQTT_USER
#define MQTT_USER              "DEIN USER"               // [MqttUser] MQTT user
#undef MQTT_PASS
#define MQTT_PASS              "DEIN PASSWORT"             // [MqttPassword] MQTT password

#undef LATITUDE
#define LATITUDE               DEIN BREITENGRAD           // [Latitude] Your location to be used with sunrise and sunset
#undef LONGITUDE
#define LONGITUDE              DEIN LÄNGENGRAD            // [Longitude] Your location to be used with sunrise and sunset
#undef APP_TIMEZONE  
#define APP_TIMEZONE           99                  // [Timezone] +1 hour (Amsterdam) (-13 .. 14 = hours from UTC, 99 = use TIME_DST/TIME_STD)
#undef APP_SLEEP 
#define APP_SLEEP              100                 // [Sleep] Sleep time to lower energy consumption (0 = Off, 1 - 250 mSec),
#undef MY_LANGUAGE
#define MY_LANGUAGE            de_DE               // German in Germany
//-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

#undef USE_DOMOTICZ
//#define USE_DOMOTICZ                             // Enable Domoticz (+6k code, +0.3k mem)
#undef USE_HOME_ASSISTANT
//#define USE_HOME_ASSISTANT                       // Enable Home Assistant Discovery Support (+7k code)
//------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

//Emulatoren
#undef USE_EMULATION_HUE 
//#define USE_EMULATION_HUE                          // Enable Hue Bridge emulation for Alexa (+14k code, +2k mem common)

#undef USE_EMULATION_WEMO
//#define USE_EMULATION_WEMO                       // Enable Belkin WeMo emulation for Alexa (+6k code, +2k mem common)
//-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

#undef USE_JAVASCRIPT_ES6
//#define USE_JAVASCRIPT_ES6
#undef USE_WEBSEND_RESPONSEdefine
//#define USE_WEBSEND_RESPONSEdefine
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

//optional
#undef ROTARY_V1
//#define ROTARY_V1                                // Add support for MI Desk Lamp
#undef USE_SONOFF_RF
//#define USE_SONOFF_RF                            // Add support for Sonoff Rf Bridge (+3k2 code)
#undef USE_RF_FLASH
//#define USE_RF_FLASH                             // Add support for flashing the EFM8BB1 chip on the Sonoff RF Bridge. C2CK must be connected to GPIO4, C2D to GPIO5 on the PCB (+2k7 code)
#undef USE_SONOFF_SC
//#define USE_SONOFF_SC                            // Add support for Sonoff Sc (+1k1 code)
#undef USE_TUYA_MCU
//#define USE_TUYA_MCU                             // Add support for Tuya
#undef USE_ARMTRONIX_DIMMERS
//#define USE_ARMTRONIX_DIMMERS                    // Add support for Armtronix Dimmers (+1k4 code)
#undef USE_PS_16_DZ
//#define USE_PS_16_DZ                             // Add support for PS-16-DZ Dimmer (+2k code)
#undef USE_SONOFF_IFAN 
//#define USE_SONOFF_IFAN                          // Add support for Sonoff iFan02 and iFan03 (+2k code)
#undef USE_BUZZER 
//#define USE_BUZZER                               // Add support for a buzzer (+0k6 code)
#undef USE_ARILUX_RF
//#define USE_ARILUX_RF                            // Add support for Arilux RF remote controller (+0k8 code, 252 iram (non 2.3.0))
#undef USE_SHUTTER 
//#define USE_SHUTTER                              // Add Shutter support for up to 4 shutter with different motortypes (+6k code)
#undef USE_DEVICE_GROUPS
//#define USE_DEVICE_GROUPS                        // Add support for device groups (+5k6 code)
#undef USE_PWM_DIMMER
//#define USE_PWM_DIMMER                           // Add support for MJ-SD01/acenx/NTONPOWER PWM dimmers (+4k5 code)
#undef USE_PWM_DIMMER_REMOTE 
//#define USE_PWM_DIMMER_REMOTE
#undef USE_SONOFF_D1
//#define USE_SONOFF_D1
#undef USE_EXS_DIMMER
//#define USE_EXS_DIMMER                           // Add support for ES-Store WiFi Dimmer (+1k5 code)
#undef EXS_MCU_CMNDS
//#define EXS_MCU_CMNDS                            // Add command to send MCU commands (+0k8 code)
//-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

//Optional light modules 
#undef USE_WS2812
//#define USE_WS2812                               // WS2812 Led string using library NeoPixelBus (+5k code, +1k mem, 232 iram) - Disable by //
#undef USE_WS2812_DMA
//#define USE_WS2812_DMA                           // DMA supports only GPIO03 (= Serial RXD) (+1k mem). When USE_WS2812_DMA is enabled expect Exceptions on Pow
#undef USE_MY92X1
//#define USE_MY92X1                               // Add support for MY92X1 RGBCW led controller as used in Sonoff B1, Ailight and Lohas
#undef USE_SM16716
//#define USE_SM16716                              // Add support for SM16716 RGB LED controller (+0k7 code)
#undef USE_SM2135
//#define USE_SM2135                               // Add support for SM2135 RGBCW led control as used in Action LSC (+0k6 code)
#undef USE_SONOFF_L1 
//#define USE_SONOFF_L1                            // Add support for Sonoff L1 led control
#undef USE_WS2812_HARDWARE  NEO_HW_WS2812
//#define USE_WS2812_HARDWARE  NEO_HW_WS2812     // Hardware type (NEO_HW_WS2812, NEO_HW_WS2812X, NEO_HW_WS2813, NEO_HW_SK6812, NEO_HW_LC8812, NEO_HW_APA106)
#undef USE_WS2812_CTYPE     NEO_GRB
//#define USE_WS2812_CTYPE     NEO_GRB           // Color type (NEO_RGB, NEO_GRB, NEO_BRG, NEO_RBG, NEO_RGBW, NEO_GRBW)
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

#undef USE_COUNTER
//#define USE_COUNTER                              // Enable inputs as counter (+0k8 code)

#undef USE_ADC_VCC
#define USE_ADC_VCC                                // Display Vcc in Power status. Disable for use as Analog input on selected devices
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

//Sensoren
#undef USE_DS18x20
//#define USE_DS18x20                              // Add support for DS18x20 sensors with id sort, single scan and read retry (+2k6 code)

#undef USE_SHT
//#define USE_SHT                                  // [I2cDriver8] Enable SHT1X sensor (+1k4 code)
#undef USE_HTU 
//#define USE_HTU                                  // [I2cDriver9] Enable HTU21/SI7013/SI7020/SI7021 sensor (I2C address 0x40) (+1k5 code)
#undef USE_BMP 
//#define USE_BMP                                  // [I2cDriver10] Enable BMP085/BMP180/BMP280/BME280 sensors (I2C addresses 0x76 and 0x77) (+4k4 code)
#undef USE_BH1750
//#define USE_BH1750                               // [I2cDriver11] Enable BH1750 sensor (I2C address 0x23 or 0x5C) (+0k5 code)

#undef USE_SHT3X
//#define USE_SHT3X                                // [I2cDriver15] Enable SHT3x (I2C address 0x44 or 0x45) or SHTC3 (I2C address 0x70) sensor (+0k7 code)

#undef USE_LM75AD
//#define USE_LM75AD                               // [I2cDriver20] Enable LM75AD sensor (I2C addresses 0x48 - 0x4F) (+0k5 code)

#undef USE_MHZ19
//#define USE_MHZ19                                // Add support for MH-Z19 CO2 sensor (+2k code)
#undef USE_SENSEAIR
//#define USE_SENSEAIR                             // Add support for SenseAir K30, K70 and S8 CO2 sensor (+2k3 code)
#undef USE_PMS5003
//#define USE_PMS5003                              // Add support for PMS5003 and PMS7003 particle concentration sensor (+1k3 code)
#undef USE_NOVA_SDS
//#define USE_NOVA_SDS                             // Add support for SDS011 and SDS021 particle concentration sensor (+1k5 code)
#undef USE_SERIAL_BRIDGE
//#define USE_SERIAL_BRIDGE                        // Add support for software Serial Bridge (+0k8 code)

#undef USE_IR_REMOTE
//#define USE_IR_REMOTE                            // Send IR remote commands using library IRremoteESP8266 and ArduinoJson (+4k3 code, 0k3 mem, 48 iram)
#undef USE_IR_RECEIVE
//#define USE_IR_RECEIVE                           // Support for IR receiver (+7k2 code, 264 iram)

#undef USE_SR04  
//#define USE_SR04                                 // Add support for HC-SR04 ultrasonic devices (+1k code)

#undef USE_HX711
//#define USE_HX711                                // Add support for HX711 load cell (+1k5 code)
#undef USE_DHT
//#define USE_DHT                                  // Add support for DHT11, AM2301 (DHT21, DHT22, AM2302, AM2321) and SI7021 Temperature and Humidity sensor (1k6 code)
#undef USE_DHT12
//  #define USE_DHT12                              // [I2cDriver41] Enable DHT12
#undef USE_VEML6070_RSET    270000 
//#define USE_VEML6070_RSET    270000              // VEML6070, Rset in Ohm used on PCB board, default 270K = 270000ohm, range for this sensor: 220K ... 1Meg
#undef USE_VEML6070_SHOW_RAW
//#define USE_VEML6070_SHOW_RAW                    // VEML6070, shows the raw value of UV-A
//----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

//Power Anzeige
#undef USE_ENERGY_MARGIN_DETECTION
//#define USE_ENERGY_MARGIN_DETECTION              // Add support for Energy Margin detection (+1k6 code)
#undef USE_ENERGY_POWER_LIMIT
//#define USE_ENERGY_POWER_LIMIT                   // Add additional support for Energy Power Limit detection (+1k2 code)
#undef USE_PZEM004T
//#define USE_PZEM004T                             // Add support for PZEM004T Energy monitor (+2k code)
#undef USE_PZEM_AC
//#define USE_PZEM_AC                              // Add support for PZEM014,016 Energy monitor (+1k1 code)
#undef USE_PZEM_DC
//#define USE_PZEM_DC                              // Add support for PZEM003,017 Energy monitor (+1k1 code)
#undef USE_MCP39F501
//#define USE_MCP39F501                            // Add support for MCP39F501 Energy monitor as used in Shelly 2 (+3k1 code)
#undef USE_ADE7953
//#define USE_ADE7953                              // [I2cDriver7] Enable ADE7953 Energy monitor as used on Shelly 2.5 (I2C address 0x38) (+1k5)
//----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

//LogLevel
#undef SERIAL_LOG_LEVEL
#define SERIAL_LOG_LEVEL       LOG_LEVEL_NONE      // [SerialLog] (LOG_LEVEL_NONE, LOG_LEVEL_ERROR, LOG_LEVEL_INFO, LOG_LEVEL_DEBUG, LOG_LEVEL_DEBUG_MORE)
                              
#endif  // _USER_CONFIG_OVERRIDE_H_
